import Footer from '@/components/Footer';
import ItineraryAccordion, { ItineraryDay } from '@/components/ItineraryAccordion';
import Navbar from '@/components/Navbar';
import { Button } from '@/components/ui/button';
import { Calendar } from '@/components/ui/calendar';
import { Slider } from '@/components/ui/slider';
import { Tabs, TabsContent, TabsList, TabsTrigger } from '@/components/ui/tabs';
import { usePage } from '@inertiajs/react';
import { Calendar as CalendarIcon, Clock, Download, Info, Users } from 'lucide-react';
import { useEffect, useState } from 'react';

const toursData = [
    {
        id: 1,
        title: 'Classic Tour',
        description:
            'Experience the vibrant spirit of Sri Lanka on this 14-day journey through lush tea plantations, ancient fortresses, and tropical coastlines. More than just stunning landscapes, it’s the people and culture that make this adventure unforgettable.',
        fullDescription:
            'For many travellers, Sri Lanka has long flown under the radar — but it’s making a strong return. Discover the vibrant colours, rich cultures, and swaying palm trees of this tropical gem. Journey through tea plantations and ancient rock fortresses on this carefully crafted 14-day tour. More than just beaches and breathtaking views, this adventure is about the inspiring people you’ll encounter along the way.',
        image: 'https://images.unsplash.com/photo-1546975490-e8b92a360b24',
        gallery: [
            'https://images.unsplash.com/photo-1546975490-e8b92a360b24',
            'https://images.unsplash.com/photo-1433086966358-54859d0ed716',
            'https://images.unsplash.com/photo-1482938289607-e9573fc25ebb',
        ],
        duration: '14 Days',
        groupSize: 'Max 15 - Minimum 5',
        ageRequirement: 'Above 10 Years',
        hotelStandard: 'Standard Accommodation',
        transport: 'Private & Some Public (Train and TukTuk)',
        physicalRating: 'Light',
        detailedItinerary: [
            {
                day: 'Day 01',
                title: 'Airport / Colombo',
                description: [
                    'Arrive at any time. An arrival transfer is included.',
                    'Welcome Moment: Meet Your Green Guide & Fellow Travellers.',
                    'Evening welcome briefing and optional group dinner.',
                ],
                activities: [{ label: 'Arrival transfer from airport' }, { label: 'Welcome meeting' }, { label: 'Optional group dinner' }],
                accommodations: [{ type: 'Hotel', name: 'Cinnamon Red Hotel' }],
                images: [
                    'https://images.unsplash.com/photo-1582719478250-c89cae4dc85b',
                    'https://images.unsplash.com/photo-1582719471384-894fbb16e074',
                ],
            },
            {
                day: 'Day 02',
                title: 'Colombo',
                description: [
                    'City tour with visits to Pettah market, Gangaramaya Temple, Fort Station, Galle Face, and more by Tuk Tuk.',
                    'Evening visit to Dutch Hospital complex for dinner.',
                ],
                activities: [{ label: 'Colombo city tour' }, { label: 'Tuk Tuk ride' }, { label: 'Dutch Hospital dinner' }],
                accommodations: [{ type: 'Hotel', name: 'Cinnamon Red Hotel' }],
                images: [
                    'https://images.unsplash.com/photo-1582719478250-c89cae4dc85b',
                    'https://images.unsplash.com/photo-1582719471384-894fbb16e074',
                ],
            },
            {
                day: 'Day 03',
                title: 'Colombo / Sigiriya',
                description: ['Visit Dambulla Rock Temple en route to Sigiriya.', 'Evening village safari and traditional dinner.'],
                activities: [{ label: 'Dambulla Rock Temple visit' }, { label: 'Village safari with dinner' }],
                accommodations: [{ type: 'Hotel', name: 'Levona Garden', alternatives: 'Into the Wild Sigiriya Hotel' }],
            },
            {
                day: 'Day 04',
                title: 'Sigiriya',
                description: [
                    'Sunrise visit to Sigiriya Rock Fortress.',
                    'Optional tour to Polonnaruwa or Ayurvedic massage.',
                    'Evening cultural show.',
                ],
                activities: [
                    { label: 'Sigiriya Rock Fortress sunrise' },
                    { label: 'Polonnaruwa city tour (optional)' },
                    { label: 'Ayurvedic massage (optional)' },
                    { label: 'Cultural show' },
                ],
                accommodations: [{ type: 'Hotel', name: 'Levona Garden', alternatives: 'Into the Wild Sigiriya Hotel' }],
            },
            {
                day: 'Day 05',
                title: 'Sigiriya / Kandy',
                description: [
                    'Optional Pidurangala Rock sunrise hike.',
                    'Spice plantation visit en route to Kandy.',
                    'City walk and visit Temple of the Tooth.',
                ],
                activities: [
                    { label: 'Pidurangala Rock hike (optional)' },
                    { label: 'Spice plantation visit' },
                    { label: 'Kandy city walk' },
                    { label: 'Temple of the Tooth Relic visit' },
                ],
                accommodations: [{ type: 'Hotel', name: 'Queens Hotel', alternatives: 'Swiss Hotel Kandy' }],
            },
            {
                day: 'Day 06',
                title: 'Kandy',
                description: ['Visit Royal Botanical Gardens.', 'Market tour and cooking class with local women (Hela Hands).'],
                activities: [{ label: 'Royal Botanical Gardens visit' }, { label: 'Cooking class with local women' }],
                accommodations: [{ type: 'Hotel', name: 'Queens Hotel', alternatives: 'Swiss Hotel Kandy' }],
            },
            {
                day: 'Day 07',
                title: 'Kandy / Nuwara Eliya',
                description: ['Visit Ramboda Waterfall and tea plantation on the way to Nuwara Eliya.', 'Free time to explore the city.'],
                activities: [{ label: 'Ramboda Waterfall visit' }, { label: 'Tea plantation tour' }],
                accommodations: [{ type: 'Hotel', name: 'In Nuwara Eliya' }],
            },
            {
                day: 'Day 08',
                title: 'Nuwara Eliya / Ella',
                description: ['Optional hike at Horton Plains.', 'Train ride from Nanu Oya to Ella.', 'Evening at leisure in Ella.'],
                activities: [{ label: 'Horton Plains hike (optional)' }, { label: 'Scenic train ride' }],
                accommodations: [{ type: 'Hotel', name: 'In Ella' }],
            },
            {
                day: 'Day 09',
                title: 'Ella',
                description: ['Visit Little Adam’s Peak.', 'Explore Nine Arches Bridge.', 'Evening at leisure.'],
                activities: [{ label: 'Little Adam’s Peak hike' }, { label: 'Nine Arches Bridge visit' }],
                accommodations: [{ type: 'Hotel', name: 'Flower Garden / Ella Gap Hotel' }],
            },
            {
                day: 'Day 10',
                title: 'Ella / Yala',
                description: ['Visit Ravana Falls en route to Yala.', 'Evening jeep safari at Yala National Park.'],
                activities: [{ label: 'Ravana Waterfall visit' }, { label: 'Yala jeep safari' }],
                accommodations: [{ type: 'Hotel', name: 'EKHO Safari Hotel' }],
            },
            {
                day: 'Day 11',
                title: 'Yala / Unawatuna',
                description: ['Visit local pottery workshop and stilt fishermen.', 'Guided walking tour at Galle Fort.'],
                activities: [{ label: 'Pottery workshop' }, { label: 'Stilt fishermen observation' }, { label: 'Galle Fort walking tour' }],
                accommodations: [{ type: 'Hotel', name: 'In Unawatuna' }],
            },
            {
                day: 'Day 12',
                title: 'Unawatuna',
                description: ['Optional whale watching tour in Mirissa.', 'Free afternoon to relax or try surfing.'],
                activities: [{ label: 'Whale watching (optional)' }, { label: 'Surfing (optional)' }],
                accommodations: [{ type: 'Hotel', name: 'In Unawatuna' }],
            },
            {
                day: 'Day 13',
                title: 'Beach Day',
                description: ['Free day in Mirissa: relax, snorkel, or surf.'],
                activities: [{ label: 'Relaxation' }, { label: 'Snorkeling (optional)' }, { label: 'Surfing (optional)' }],
                accommodations: [{ type: 'Hotel', name: 'In Unawatuna' }],
            },
            {
                day: 'Day 14',
                title: 'Departure',
                description: ['Private or public transfer to Colombo airport. Depart any time.'],
                activities: [{ label: 'Airport transfer assistance' }],
            },
        ],
        includes: [
            '13 nights accommodation (twin sharing)',
            '13 breakfasts, 1 lunch, 1 dinner',
            'Air-conditioned private vehicle',
            'Train ride from Nanu Oya to Ella (2nd or 3rd class)',
            'All entrance fees listed',
            'English-speaking national tour guide',
            'Cooking class with local women',
            'Village safari with dinner',
            'All government taxes',
            'Local vehicle insurance and fuel',
            'Airport transfers',
        ],
        excludes: [
            'International flights',
            'Travel insurance',
            'Personal expenses',
            'Optional activities',
            'Tips for guides and drivers',
            'Camera/video permits at certain sites',
        ],
    },
    {
        id: 2,
        title: 'Sri Lanka 12-Day Experience',
        description:
            'Dive deep into Sri Lanka’s culture, wildlife, and natural beauty in this immersive 12-day journey. From ancient rock fortresses to misty highlands and golden beaches, this tour is packed with unforgettable moments.',
        fullDescription:
            "This 12-day adventure takes you through Sri Lanka’s most iconic destinations. Begin in bustling Colombo, journey through cultural heartlands like Sigiriya and Kandy, ride one of the world's most scenic trains to Ella, go on safari in Udawalawe, and relax in the tropical beach town of Mirissa. This journey blends heritage, wildlife, and coastal leisure into one rich travel experience.",
        image: 'https://images.unsplash.com/photo-1575469008803-71fa2e8a30a4',
        gallery: [
            'https://images.unsplash.com/photo-1575469008803-71fa2e8a30a4',
            'https://images.unsplash.com/photo-1564007761463-b49a1f179c03',
            'https://images.unsplash.com/photo-1625301840055-d6406752d6c0',
        ],
        duration: '12 Days',
        groupSize: 'Max 15 - Minimum 5',
        ageRequirement: 'Above 10 Years',
        hotelStandard: 'Standard Accommodation',
        transport: 'Private Vehicle, Mini Coach/Bus & Train',
        physicalRating: 'Light',
        detailedItinerary: [
            {
                day: 'Day 01',
                title: 'Airport / Colombo',
                description: ['Arrive at any time. Airport transfer included.', 'Welcome meeting and dinner in the late afternoon.'],
                activities: [{ label: 'Airport pickup' }, { label: 'Welcome dinner' }],
                accommodations: [{ type: 'Hotel', name: 'Sofia Hotel Colombo / Cinnamon Red Hotel' }],
            },
            {
                day: 'Day 02',
                title: 'Colombo',
                description: [
                    'Explore Colombo city including Pettah market, Fort station, Gangaramaya Temple, Galle Face, BMICH, and Torrington by Tuk Tuk.',
                    'Evening visit to Dutch Hospital complex for dinner.',
                ],
                activities: [{ label: 'Colombo city tour' }, { label: 'Tuk Tuk ride' }, { label: 'Dutch Hospital dinner' }],
                accommodations: [{ type: 'Hotel', name: 'Sofia Hotel Colombo / Cinnamon Red Hotel' }],
            },
            {
                day: 'Day 03',
                title: 'Colombo / Sigiriya',
                description: [
                    'Transfer to Sigiriya (approx. 3.5 hours).',
                    'Visit Dambulla Rock Temple.',
                    'Evening village safari in Habarana and traditional dinner.',
                ],
                activities: [{ label: 'Dambulla Rock Temple' }, { label: 'Village safari with dinner' }],
                accommodations: [{ type: 'Hotel', name: 'Levona Garden / Into the Wild Sigiriya' }],
            },
            {
                day: 'Day 04',
                title: 'Sigiriya',
                description: [
                    'Sunrise visit to Sigiriya Rock Fortress.',
                    'Optional visit to Polonnaruwa or Ayurvedic massage.',
                    'Evening cultural show in Habarana.',
                ],
                activities: [
                    { label: 'Sigiriya Rock Fortress' },
                    { label: 'Polonnaruwa tour (optional)' },
                    { label: 'Ayurvedic massage (optional)' },
                    { label: 'Cultural show' },
                ],
                accommodations: [{ type: 'Hotel', name: 'Levona Garden / Into the Wild Sigiriya' }],
            },
            {
                day: 'Day 05',
                title: 'Sigiriya / Kandy',
                description: [
                    'Sunrise hike to Pidurangala Rock.',
                    'Transfer to Kandy (approx. 3 hours).',
                    'Visit spice plantation en route.',
                    'Evening Kandy city walk and Temple of the Tooth Relic visit.',
                ],
                activities: [
                    { label: 'Pidurangala Rock sunrise hike' },
                    { label: 'Spice plantation visit' },
                    { label: 'Kandy city tour' },
                    { label: 'Temple of the Tooth visit' },
                ],
                accommodations: [{ type: 'Hotel', name: 'Queens Hotel / Swiss Hotel Kandy' }],
            },
            {
                day: 'Day 06',
                title: 'Kandy',
                description: ['Visit Royal Botanical Gardens.', 'Market tour and Sri Lankan cooking class.'],
                activities: [{ label: 'Royal Botanical Gardens' }, { label: 'Cooking class and market walk' }],
                accommodations: [{ type: 'Hotel', name: 'Queens Hotel / Swiss Hotel Kandy' }],
            },
            {
                day: 'Day 07',
                title: 'Kandy / Nuwara Eliya / Ella',
                description: [
                    'Transfer to Nuwara Eliya (approx. 2.5 hours).',
                    'Visit Ramboda Falls and tea plantation/factory.',
                    'Scenic train ride from Nanu Oya to Ella (approx. 3 hours).',
                ],
                activities: [{ label: 'Ramboda Waterfall' }, { label: 'Tea plantation and factory' }, { label: 'Scenic train ride' }],
                accommodations: [{ type: 'Hotel', name: 'Flower Garden / Ella Gap Hotel' }],
            },
            {
                day: 'Day 08',
                title: 'Ella',
                description: ['Morning hike to Little Adam’s Peak.', 'Visit Nine Arches Bridge.', 'Evening at leisure.'],
                activities: [{ label: 'Little Adam’s Peak' }, { label: 'Nine Arches Bridge' }],
                accommodations: [{ type: 'Hotel', name: 'Flower Garden / Ella Gap Hotel' }],
            },
            {
                day: 'Day 09',
                title: 'Ella / Udawalawe',
                description: ['Visit Ravana Falls.', 'Visit Elephant Transit Home and jeep safari in Udawalawe National Park.'],
                activities: [{ label: 'Ravana Falls' }, { label: 'Elephant Transit Home' }, { label: 'Udawalawe jeep safari' }],
                accommodations: [{ type: 'Hotel', name: 'Athgira River Camp' }],
            },
            {
                day: 'Day 10',
                title: 'Udawalawe / Mirissa',
                description: ['Transfer to Mirissa (approx. 2 hours).', 'Surfing lesson at Weligama Beach.', 'Evening visit to Galle Fort.'],
                activities: [{ label: 'Surfing lesson' }, { label: 'Galle Fort' }],
                accommodations: [{ type: 'Hotel', name: 'Randiya Sea View / Mimoza Mirissa' }],
            },
            {
                day: 'Day 11',
                title: 'Mirissa',
                description: ['Leisure day at the beach.', 'Optional: Whale watching or additional surfing session.'],
                activities: [{ label: 'Beach relaxation' }, { label: 'Whale watching (optional)' }, { label: 'Surfing (optional)' }],
                accommodations: [{ type: 'Hotel', name: 'Randiya Sea View / Mimoza Mirissa' }],
            },
            {
                day: 'Day 12',
                title: 'Departure',
                description: ['Departure anytime or extend your stay with assistance from your guide.'],
                activities: [{ label: 'Airport transfer or onward planning assistance' }],
            },
        ],
        includes: [
            '11 nights accommodation (twin sharing) with breakfast',
            'Private air-conditioned vehicle or mini coach',
            'Train ride (2nd/3rd class reserved)',
            'All entrance fees for listed sights and experiences',
            '1 surfing lesson',
            'English-speaking chauffeur guide',
            'Airport pickup and drop off',
            'All government taxes',
            'Fuel and local insurance',
        ],
        excludes: [
            'International airfare',
            'Sightseeing not specified',
            'Meals not mentioned',
            'Travel insurance',
            'Camera & video permits',
            'Tips and personal expenses',
            'Early check-in / late checkout fees',
        ],
    },
    {
        id: 3,
        title: 'Sri Lanka Highlights Tour',
        description:
            'Experience a thrilling 8-day adventure through Sri Lanka’s cultural and natural highlights. From ancient temples and iconic rock fortresses to lush tea plantations and golden beaches, this journey offers a perfect blend of discovery and relaxation.',
        fullDescription:
            'On this carefully curated 8-day journey through Sri Lanka, uncover a land rich in history, culture, and natural beauty. Explore the majestic Sigiriya Rock Fortress, witness wildlife in Minneriya and Udawalawe, and enjoy a scenic train ride through tea country. Relax in the historic city of Galle and unwind on the golden beaches of Unawatuna. Perfect for those looking to experience the best of Sri Lanka in just over a week.',
        image: 'https://images.unsplash.com/photo-1603712256877-98259e7c50f6',
        gallery: [
            'https://images.unsplash.com/photo-1582719471384-894fbb16e074',
            'https://images.unsplash.com/photo-1552733407-5d5c46c3bb3b',
            'https://images.unsplash.com/photo-1625049423259-a83656deb0b5',
        ],
        duration: '8 Days',
        groupSize: 'Max 15 - Minimum 5',
        ageRequirement: 'Above 10 Years',
        hotelStandard: 'Standard Accommodation',
        transport: 'Private & Train',
        physicalRating: 'Light',
        detailedItinerary: [
            {
                day: 'Day 01',
                title: 'Airport / Negombo',
                description: [
                    'Meet and greet at Colombo International Airport.',
                    'Transfer to Negombo (approx. 30 min).',
                    'Check in and relax at the hotel.',
                ],
                activities: [{ label: 'Airport pickup' }, { label: 'Transfer to Negombo' }],
                accommodations: [{ type: 'Hotel', name: 'Sea Horse Hotel' }],
            },
            {
                day: 'Day 02',
                title: 'Negombo / Sigiriya',
                description: [
                    'Transfer to Sigiriya (approx. 3 hours).',
                    'Visit Dambulla Rock Cave Temple en route.',
                    'Enjoy lunch at a local village.',
                ],
                activities: [{ label: 'Dambulla Rock Cave Temple visit' }, { label: 'Local village lunch' }],
                accommodations: [{ type: 'Hotel', name: 'Hotel Sigiriya' }],
            },
            {
                day: 'Day 03',
                title: 'Sigiriya',
                description: [
                    'Sunrise hike to Sigiriya Rock Fortress.',
                    'Relax at hotel until afternoon.',
                    'Evening safari in Minneriya National Park to witness the elephant gathering.',
                ],
                activities: [{ label: 'Sigiriya Rock Fortress hike' }, { label: 'Minneriya National Park safari' }],
                accommodations: [{ type: 'Hotel', name: 'Hotel Sigiriya' }],
            },
            {
                day: 'Day 04',
                title: 'Sigiriya / Kandy',
                description: [
                    'Transfer to Kandy (approx. 3 hours).',
                    'Optional visit to Matale spice garden.',
                    'Walking tour of Kandy city.',
                    'Visit Temple of the Sacred Tooth Relic.',
                ],
                activities: [
                    { label: 'Matale spice garden tour (optional)' },
                    { label: 'Kandy city walking tour' },
                    { label: 'Temple of the Tooth visit' },
                ],
                accommodations: [{ type: 'Hotel', name: 'Thilanka Hotel Kandy' }],
            },
            {
                day: 'Day 05',
                title: 'Kandy / Nuwara Eliya / Ella',
                description: [
                    'Drive to Nuwara Eliya (approx. 3 hours).',
                    'Visit a tea plantation and factory.',
                    'Board train from Nanu Oya to Ella (approx. 3 hours) for one of the world’s most scenic rides.',
                ],
                activities: [{ label: 'Tea plantation and factory visit' }, { label: 'Scenic train ride to Ella' }],
                accommodations: [{ type: 'Hotel', name: 'Serenite Ella' }],
            },
            {
                day: 'Day 06',
                title: 'Ella / Udawalawa / Unawatuna',
                description: [
                    'Morning visit to Little Adam’s Peak and Nine Arches Bridge.',
                    'Drive to Unawatuna with a visit to Udawalawe Elephant Transit Home en route.',
                    'Afternoon visit to Galle Fort, a UNESCO World Heritage Site.',
                ],
                activities: [
                    { label: 'Little Adam’s Peak hike' },
                    { label: 'Nine Arches Bridge visit' },
                    { label: 'Udawalawe Elephant Transit Home visit' },
                    { label: 'Galle Fort walking tour' },
                ],
                accommodations: [{ type: 'Hotel', name: 'Agnus Unawatuna Hotel' }],
            },
            {
                day: 'Day 07',
                title: 'Unawatuna',
                description: ['Free day at leisure. Relax on the beach or explore the area.'],
                activities: [{ label: 'Leisure day at beach' }],
                accommodations: [{ type: 'Hotel', name: 'Agnus Unawatuna Hotel' }],
            },
            {
                day: 'Day 08',
                title: 'Departure',
                description: ['Breakfast at the hotel.', 'Transfer to the airport for departure.'],
                activities: [{ label: 'Transfer to airport' }],
            },
        ],
        includes: [
            '7 nights accommodation',
            'Daily breakfast',
            'Private air-conditioned transportation',
            'Train ride from Nanu Oya to Ella',
            'Entrance to Dambulla Temple, Sigiriya Rock, Minneriya Safari, Temple of the Tooth',
            'Visit to Udawalawe Elephant Transit Home and Galle Fort',
            'English-speaking guide',
            'Airport transfers',
        ],
        excludes: ['International airfare', 'Travel insurance', 'Personal expenses', 'Optional activities', 'Tips and gratuities', 'Camera permits'],
    },

    {
        id: 4,
        title: 'Wildlife Safari Adventure',
        description: 'Spot elephants, leopards and exotic birds in Yala and Udawalawe National Parks.',
        fullDescription:
            "Embark on an unforgettable wildlife safari through Sri Lanka's most renowned national parks, home to a remarkable diversity of animals including the elusive Sri Lankan leopard. Your adventure begins at Udawalawe National Park, famous for its large elephant population where sightings are virtually guaranteed. Watch these magnificent creatures in their natural habitat, often gathering in herds around the park's reservoir. Next, venture into Yala National Park, which boasts one of the highest leopard densities in the world. Expert trackers will guide your jeep safaris, helping you spot not just leopards but also sloth bears, crocodiles, deer, and numerous bird species. The tour includes visits to elephant transit homes where orphaned elephants are rehabilitated before being released back into the wild. Throughout your journey, stay in carefully selected eco-friendly accommodations that blend comfort with wilderness experiences, some offering spectacular views over watering holes where animals gather at dawn and dusk.",
        image: 'https://images.unsplash.com/photo-1581266509647-0dfd9c3fb8fb',
        gallery: [
            'https://images.unsplash.com/photo-1581266509647-0dfd9c3fb8fb',
            'https://images.unsplash.com/photo-1509316975850-ff9c5deb0cd9',
            'https://images.unsplash.com/photo-1518495973542-4542c06a5843',
        ],
        duration: '4 Days',
        location: 'Yala, Udawalawe',
        groupSize: '2-6',
        price: '$599',
        itinerary: [
            {
                day: 'Day 1',
                title: 'Colombo to Udawalawe',
                description: 'Transfer from Colombo to Udawalawe. Afternoon safari in Udawalawe National Park.',
            },
            {
                day: 'Day 2',
                title: 'Elephant Transit Home & Yala',
                description: 'Morning visit to Elephant Transit Home. Transfer to Yala. Afternoon safari in Yala National Park.',
            },
            {
                day: 'Day 3',
                title: 'Full Day at Yala',
                description: 'Early morning and late afternoon safaris in Yala National Park, maximizing chances of leopard sightings.',
            },
            {
                day: 'Day 4',
                title: 'Return to Colombo',
                description: 'Final morning safari. Return to Colombo with stops at scenic points along the coast.',
            },
        ],
        includes: [
            '3 nights accommodation',
            'Daily breakfast and select meals',
            'All jeep safaris with experienced tracker',
            'Park entrance fees',
            'All transportation in air-conditioned vehicles',
            'English-speaking naturalist guide',
            'Entrance to Elephant Transit Home',
        ],
        excludes: [
            'International flights',
            'Travel insurance',
            'Personal expenses',
            'Camera/video permits in parks',
            'Alcoholic beverages',
            'Tips for guides and drivers',
        ],
    },
];

type Tour = (typeof toursData)[number];

const TourDetail = () => {
    const { props } = usePage();
    const id = props.id;
    const [tour, setTour] = useState<Tour | null>(null);
    const [activeImageIndex, setActiveImageIndex] = useState(0);
    const [isLoading, setIsLoading] = useState(true);
    // Fix: Use proper Date type for the date state
    const [date, setDate] = useState<Date | undefined>(undefined);
    const [travelers, setTravelers] = useState(2);

    useEffect(() => {
        // Simulate API fetch with a short delay
        const loadTour = async () => {
            setIsLoading(true);
            // Find the tour with the matching id
            const foundTour = toursData.find((t) => t.id === parseInt(String(id)));
            await new Promise((resolve) => setTimeout(resolve, 500));
            setTour(foundTour ?? null);
            setIsLoading(false);
        };

        loadTour();
    }, [id]);

    // Handle PDF download
    const handleDownloadPdf = () => {
        if (tour) {
            //generateItineraryPDF(tour.title, tour.detailedItinerary || tour.itinerary);
        }
    };

    if (isLoading) {
        return (
            <div className="min-h-screen">
                <Navbar />
                <div className="container mx-auto px-4 pt-20">
                    <div className="flex min-h-[50vh] items-center justify-center">
                        <div className="text-primary animate-pulse text-lg">Loading...</div>
                    </div>
                </div>
                <Footer />
            </div>
        );
    }

    if (!tour) {
        return (
            <div className="min-h-screen">
                <Navbar />
                <div className="container mx-auto px-4 pt-24">
                    <div className="flex min-h-[50vh] flex-col items-center justify-center">
                        <h1 className="font-display text-primary mb-4 text-3xl font-bold">Tour Not Found</h1>
                        <p className="mb-8 text-gray-600">The tour you're looking for doesn't exist or has been removed.</p>
                        <Button asChild>
                            <a href="/tours">Back to Tours</a>
                        </Button>
                    </div>
                </div>
                <Footer />
            </div>
        );
    }

    return (
        <div className="min-h-screen">
            <Navbar />
            <div className="pt-20 pb-16">
                {/* Hero Section */}
                <div className="relative h-[50vh] overflow-hidden">
                    <img src={tour.gallery[activeImageIndex]} alt={tour.title} className="h-full w-full object-cover" />
                    <div className="absolute inset-0 flex items-end bg-gradient-to-t from-black/70 to-transparent">
                        <div className="container mx-auto px-4 pb-8">
                            <div className="animate-fade-in">
                                <h1 className="font-display mb-4 text-4xl font-bold text-white md:text-5xl">{tour.title}</h1>
                                <div className="mt-4 flex flex-wrap gap-4 text-white">
                                    <span className="flex items-center gap-1">
                                        <Clock size={18} />
                                        {tour.duration}
                                    </span>
                                    <span className="flex items-center gap-1">
                                        <Users size={18} />
                                        {tour.groupSize} people
                                    </span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div className="container mx-auto mt-8 px-4">
                    {/* Gallery Thumbnails */}
                    <div className="mb-8 flex gap-2 overflow-x-auto pb-2">
                        {tour.gallery.map((img, index) => (
                            <div
                                key={index}
                                className={`h-16 w-24 flex-shrink-0 cursor-pointer border-2 transition-all ${activeImageIndex === index ? 'border-primary scale-105' : 'border-transparent'}`}
                                onClick={() => setActiveImageIndex(index)}
                            >
                                <img src={img} alt={`${tour.title} - Image ${index + 1}`} className="h-full w-full object-cover" />
                            </div>
                        ))}
                    </div>

                    {/* Tour Content */}
                    <div className="grid grid-cols-1 gap-8 lg:grid-cols-3">
                        {/* Left Column - Tour Details with Tabs */}
                        <div className="animate-fade-in space-y-8 lg:col-span-2">
                            <Tabs defaultValue="overview" className="w-full">
                                <TabsList className="grid w-full grid-cols-3">
                                    <TabsTrigger value="overview" className="text-base">
                                        Overview
                                    </TabsTrigger>
                                    <TabsTrigger value="itinerary" className="text-base">
                                        Itinerary
                                    </TabsTrigger>
                                    <TabsTrigger value="details" className="text-base">
                                        Tour Details
                                    </TabsTrigger>
                                </TabsList>

                                {/* Overview Tab */}
                                <TabsContent value="overview" className="mt-6">
                                    <div className="rounded-lg bg-white p-6 shadow-md">
                                        <div className="mb-4 flex items-center justify-between">
                                            <h2 className="font-display text-2xl font-bold text-gray-900">Tour Overview</h2>
                                            <Button
                                                onClick={handleDownloadPdf}
                                                variant="outline"
                                                className="border-primary text-primary hover:bg-primary/10"
                                            >
                                                <Download size={18} className="mr-2" />
                                                Download PDF
                                            </Button>
                                        </div>
                                        <p className="leading-relaxed text-gray-700">{tour.fullDescription}</p>
                                    </div>
                                </TabsContent>

                                {/* Itinerary Tab - Updated with Accordion */}
                                <TabsContent value="itinerary" className="mt-6">
                                    {tour.detailedItinerary ? (
                                        <ItineraryAccordion
                                            itineraryDays={tour.detailedItinerary as ItineraryDay[]}
                                            onDownloadPdf={handleDownloadPdf}
                                        />
                                    ) : (
                                        <div className="rounded-lg bg-white p-6 shadow-md">
                                            <div className="mb-4 flex items-center justify-between">
                                                <h2 className="font-display mb-4 text-2xl font-bold text-gray-900">Day by Day Itinerary</h2>
                                                <Button
                                                    onClick={handleDownloadPdf}
                                                    variant="outline"
                                                    className="border-primary text-primary hover:bg-primary/10"
                                                >
                                                    <Download size={18} className="mr-2" />
                                                    Download PDF
                                                </Button>
                                            </div>
                                            <div className="space-y-4">
                                                {tour.itinerary.map((item, index) => (
                                                    <div key={index} className="border-b border-gray-200 pb-4 last:border-0 last:pb-0">
                                                        <div className="mb-2 flex flex-col gap-2 md:flex-row md:items-center">
                                                            <span className="bg-primary rounded-full px-3 py-1 text-sm font-medium text-white">
                                                                {item.day}
                                                            </span>
                                                            <h3 className="font-display text-xl font-semibold">{item.title}</h3>
                                                        </div>
                                                        <p className="text-gray-700">{item.description}</p>
                                                    </div>
                                                ))}
                                            </div>
                                        </div>
                                    )}
                                </TabsContent>

                                {/* Tour Details Tab */}
                                <TabsContent value="details" className="mt-6">
                                    <div className="rounded-lg bg-white p-6 shadow-md">
                                        <h2 className="font-display mb-4 text-2xl font-bold text-gray-900">What's Included</h2>
                                        <div className="grid grid-cols-1 gap-6 md:grid-cols-2">
                                            <div className="space-y-4">
                                                <h3 className="font-display text-primary mb-3 flex items-center text-xl font-bold">
                                                    <Info className="mr-2" size={20} />
                                                    Included
                                                </h3>
                                                <ul className="space-y-2">
                                                    {tour.includes.map((item, index) => (
                                                        <li key={index} className="flex items-start">
                                                            <span className="mt-1 mr-2 text-green-500">✓</span>
                                                            <span>{item}</span>
                                                        </li>
                                                    ))}
                                                </ul>
                                            </div>
                                            <div className="space-y-4">
                                                <h3 className="font-display text-primary mb-3 flex items-center text-xl font-bold">
                                                    <Info className="mr-2" size={20} />
                                                    Not Included
                                                </h3>
                                                <ul className="space-y-2">
                                                    {tour.excludes.map((item, index) => (
                                                        <li key={index} className="flex items-start">
                                                            <span className="mt-1 mr-2 text-red-500">✗</span>
                                                            <span>{item}</span>
                                                        </li>
                                                    ))}
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                </TabsContent>
                            </Tabs>
                        </div>

                        {/* Right Column - Booking */}
                        <div className="lg:col-span-1">
                            <div className="animate-fade-in sticky top-24 rounded-lg bg-white p-6 shadow-md">
                                <div className="mb-4">
                                    <p className="text-gray-500">per person</p>
                                </div>

                                <div className="mb-6 space-y-4">
                                    <div className="flex items-center text-gray-700">
                                        <CalendarIcon className="mr-2" size={18} />
                                        <span>Select Date:</span>
                                    </div>

                                    {/* Calendar Popover - Fixed date handling */}
                                    <div className="rounded-md border border-gray-200">
                                        <Calendar
                                            mode="single"
                                            selected={date}
                                            onSelect={setDate}
                                            initialFocus
                                            disabled={(date) => date < new Date()}
                                            className="w-full rounded-md"
                                        />
                                    </div>

                                    <div className="flex items-center justify-between text-gray-700">
                                        <div className="flex items-center">
                                            <Users className="mr-2" size={18} />
                                            <span>Travelers: {travelers} people</span>
                                        </div>
                                    </div>
                                    <Slider
                                        defaultValue={[2]}
                                        max={12}
                                        min={1}
                                        step={1}
                                        value={[travelers]}
                                        onValueChange={(value) => setTravelers(value[0])}
                                    />
                                </div>

                                <Button className="mb-4 w-full">Book Now</Button>
                                <Button variant="outline" className="w-full">
                                    Inquire
                                </Button>

                                <div className="mt-6 border-t border-gray-200 pt-6">
                                    <h4 className="mb-2 font-semibold">Need Help?</h4>
                                    <p className="mb-3 text-sm text-gray-600">Our travel experts are ready to assist you with any questions.</p>
                                    <div className="text-primary font-medium">+94 77 123 4567</div>
                                    <div className="text-primary font-medium">info@ceylon-adventures.com</div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <Footer />
        </div>
    );
};

export default TourDetail;
